// ================================================================
// GenomeMixer    (c) 2003, Alex Williams
// All rights reserved.
// Send email correspondence to Robert W. Williams <rwilliam@nb.utmem.edu>
// at the University of Tennesse Health Science Center

// This project was funded jointly by the National Institute of Mental Health, National Institute on Drug Abuse,
// and the National Science Foundation (award P20-MH 62009 to KFM and RW)

// This source code may be used according to the terms of the GNU General Public License (GPL).
// See www.gnu.org for specifics. Essentially, the source may be freely used as long as the source code
// for whatever program the source is also made freely available. If you want to use this source
// in a closed-source program, you should email us for licensing options.

// Disclaimer: This code comes with no warranty at all, and there is no guarantee that it will
// work as claimed in the documentation. Hopefully, it will be useful anyway.

// Note that GenomeMixer makes use of the Trolltech Qt toolkit for its window-managing needs.
// There is very little use of Qt data structures (aside from QString) in the actual processing code,
// but **you will need to have Qt installed in order to compile this code.** Check <www.trolltech.com>
// for details; there should be a free GPL-software-only version of Qt available on the Trolltech
// web site.

// Any redistributions of this software in code or binary form must include the
// above copyright notice, licensing information, disclaimer, and this notice itself.
// Basically, all the comments at the top of this file must be retained.
// ================================================================


#include "GeneRange.h"
#include <iostream>
#include <string>

using namespace std;

GeneRange::GeneRange(long newStart, long newEnd, int newValue) {
    // Note that start and end can be the same. This is a precise "gene."    
    if ((newStart < 0) || (newEnd < 0) || (newEnd < newStart)) {
	cerr << "We tried to make a GeneRange with invalid parameters.\n";
	cerr << "The parameters passed were (start, end, value) = ("
		<< newStart << ", "
		<< newEnd << ", "
		<< newValue << ").\n";
	cerr << "The start and end must be non-negative, and that the end cannot be before the start (although the two can be equal).\n";
	exit(1);
    }    
    theStart = newStart;
    theEnd   = newEnd;
    theValue = newValue;
    genWhenRecombined = -1; // the generation at which this recombination occurred (not used right now)
}

int GeneRange::value() {
  return theValue;	
}

long GeneRange::start() {
  return theStart;	
} 

long GeneRange::end() {	
  return theEnd;	
}

int  GeneRange::whenRecombined() {
  return genWhenRecombined;
}

bool GeneRange::contains(long theGeneLocation) {
    // returns true or false, based on whether or not "theGeneLocation" lies
    // between theStart and theEnd
    return (theGeneLocation >= theStart && theGeneLocation <= theEnd);
}


